@@ -4,8 +4,10 @@
 
 import sys
 
-import aliascore as core
 import click
+
+import aliascore as core
+
 from __init__ import __version__
 
 
@@ -137,6 +139,12 @@ def version(ctx) -> None:
     print_version(ctx, ver=True)
 
 
+@cli.command()
+def hint() -> None:
+    """Print all hints."""
+    core.print_all_hint()
+
+
 @cli.command(name="history")
 @click.pass_context
 def top_history(ctx) -> None:
